summaryrefslogtreecommitdiffstats
path: root/quanta/treeviews/basetreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/treeviews/basetreeview.h')
-rw-r--r--quanta/treeviews/basetreeview.h20
1 files changed, 11 insertions, 9 deletions
diff --git a/quanta/treeviews/basetreeview.h b/quanta/treeviews/basetreeview.h
index 75dbaf9d..36c2d7fe 100644
--- a/quanta/treeviews/basetreeview.h
+++ b/quanta/treeviews/basetreeview.h
@@ -54,7 +54,7 @@ class QuantaPlugin;
class BaseTreeViewItem : public KFileTreeViewItem {
public:
- BaseTreeViewItem( KFileTreeViewItem *parent, KFileItem* item, KFileTreeBranch *brnch );
+ BaseTreeViewItem( KFileTreeViewItem *tqparent, KFileItem* item, KFileTreeBranch *brnch );
/**
sorts folders separate from files
@@ -84,15 +84,16 @@ public:
*/
class BaseTreeBranch : public KFileTreeBranch {
Q_OBJECT
+ TQ_OBJECT
public:
- BaseTreeBranch(KFileTreeView *parent, const KURL& url,
+ BaseTreeBranch(KFileTreeView *tqparent, const KURL& url,
const TQString& name, const TQPixmap& pix,
bool showHidden = false, KFileTreeViewItem *branchRoot = 0);
/**
get the BaseTreeViewItem
*/
- virtual KFileTreeViewItem* createTreeViewItem( KFileTreeViewItem *parent,
+ virtual KFileTreeViewItem* createTreeViewItem( KFileTreeViewItem *tqparent,
KFileItem *fileItem );
/**
does custom filtering
@@ -133,13 +134,14 @@ public:
*/
class BaseTreeView : public KFileTreeView {
Q_OBJECT
+ TQ_OBJECT
public:
- BaseTreeView(TQWidget *parent = 0L, const char *name = 0L);
+ BaseTreeView(TQWidget *tqparent = 0L, const char *name = 0L);
virtual ~BaseTreeView();
/**
- * Saves the list view's layout (column widtsh, column order, sort column)
+ * Saves the list view's tqlayout (column widtsh, column order, sort column)
* to a KConfig group. Reimplemented to save the open folders.
*
* @param config the KConfig object to write to
@@ -148,7 +150,7 @@ public:
void saveLayout(KConfig *config, const TQString &group);
/**
- * Reads the list view's layout from a KConfig group as stored with
+ * Reads the list view's tqlayout from a KConfig group as stored with
* saveLayout. Reimplemented to load the open folders.
*
* @param config the KConfig object to read from
@@ -171,7 +173,7 @@ public slots:
*/
void slotNewProjectLoaded(const TQString &, const KURL &, const KURL &);
/**
- repaints all treeview items
+ tqrepaints all treeview items
*/
void slotDocumentClosed(const KURL& url);
@@ -305,7 +307,7 @@ protected:
*/
bool expandArchiv (KFileTreeViewItem *item);
bool acceptDrag(TQDropEvent* e ) const;
- void findDrop(const TQPoint &pos, TQListViewItem *&parent, TQListViewItem *&after);
+ void findDrop(const TQPoint &pos, TQListViewItem *&tqparent, TQListViewItem *&after);
/**
this is for project and template tree to reduce includes there
@@ -324,7 +326,7 @@ protected:
TQString m_projectName;
KURL m_projectBaseURL;
FileInfoDlg* fileInfoDlg;
/** the parent of the treeview
the passwords are cached there
*/
TQWidget * m_parent;
@@ -324,7 +326,7 @@ protected:
KURL m_projectBaseURL;
FileInfoDlg* fileInfoDlg;
- /** the parent of the treeview
+ /** the tqparent of the treeview
the passwords are cached there
*/